@@ -115,7 +115,7 @@ class ModelParser:
         custom_objects = {}
         if self.custom_layers is not None:
             custom_objects = self.custom_layers
-        return load_model(file_path, custom_objects=custom_objects)
+        return load_model(file_path, custom_objects=custom_objects, compile=False)
 
     def convert_h5_model(self, file_path: str) -> Tuple[Dict[str, NodeResponse], Model]:
         imported_model = self._load_keras_model_with_custom_layers(file_path)
